==> kyamo_0.13.99+0.2a.orig.tar.gz: kyamo-0.2a/src/cdparanoia-interface.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert   *
 *   roweigert@t-online.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

using namespace std;
#ifndef _CDPARANOIAINTERFACE_H_
#define _CDPARANOIAINTERFACE_H_

#include <qstring.h>
#include <qfile.h>
#include <kprocess.h>
#include <qstringlist.h>

#include <iostream>

#include "progress.h"
#include "mysqlinterface.h"
#include "rcdatei.h"
#include "cdidgenerator.h"

class compactdisc : public QObject
  {
    Q_OBJECT
  public:
    compactdisc();
    ~compactdisc();
    progresswithbar *progress;
    long startsector;
    long processedsectors;
    QString discid;
    QString cddbquery;
    cdrominfo *cdcontent;
    KProcess *cdparanoiaProcess;
  public slots:
    void readprogressinfo(KProcess *,char *,int);
    void getTrack(int,QString,progressmainwindow *);
  };

#endif //_CDPARANOIAINTERFACE_H_

==> kyamo_0.40+0.4a.orig.tar.gz: kyamo-0.40a4-2/src/cdparanoia-interface.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert   *
 *   roweigert@t-online.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

using namespace std;
#ifndef _CDPARANOIAINTERFACE_H_
#define _CDPARANOIAINTERFACE_H_

#include <qstring.h>
#include <qfile.h>
#include <kprocess.h>
#include <qstringlist.h>
#include <qmessagebox.h>

#include <iostream>

#include "progress.h"
#include "databasewrapper.h"
#include "rcdatei.h"
#include "cdidgenerator.h"

class compactdisc : public QObject
  {
    Q_OBJECT
  public:
    compactdisc();
    ~compactdisc();
    progressmainwindow *progresswindow;
    progresswithbar *progress;
    long startsector;
    long processedsectors;
    QString discid;
    QString cddbquery;
    cdrominfo *cdcontent;
    KProcess *cdparanoiaProcess;
  public slots:
    void readprogressinfo(KProcess *,char *,int);
    void getTrack(int,QString,progressmainwindow *);
  };

#endif //_CDPARANOIAINTERFACE_H_
